@@ -1,19 +1,23 @@
 from .DeckGLMap import DeckGLMap
+from .GroupTree import GroupTree
 from .HistoryMatch import HistoryMatch
 from .LayeredMap import LayeredMap
 from .LeafletMap import LeafletMap
 from .Map import Map
 from .Morris import Morris
 from .PriorPosteriorDistribution import PriorPosteriorDistribution
+from .VectorSelector import VectorSelector
 from .WellCompletions import WellCompletions
 
 __all__ = [
     "DeckGLMap",
+    "GroupTree",
     "HistoryMatch",
     "LayeredMap",
     "LeafletMap",
     "Map",
     "Morris",
     "PriorPosteriorDistribution",
+    "VectorSelector",
     "WellCompletions"
 ]
\ No newline at end of file
